//
// PovRay scene file for a simple wooden cabinet
//
// Author:   Hj. Malthaner
// Email:    hansjoerg.malthaner@gmx.de
// Creation:  2009/06/07
// Update:    2009/12/09
//
// Web:      http://www.funkelwerk.de
// Forum:    http://www.funkelwerk.de/forum
//
// This file is available under the GNU general
// public license v2 or newer.
//
// http://www.gnu.org/licenses/gpl-2.0.html
//
  
#declare Cam1 = 
camera 
{
  orthographic
  location < 2.5, 2.5*0.82, 2.5 >*1.4
  look_at < 0, 0, 0 >
}

camera 
{
  Cam1 
}

light_source 
{ 
  < 2.5*20, 100, 2.5*10 >
  color rgb < 1, 1, 1 > 
}

// sky sphere

sphere 
{
  <0,0,0>, 10000

  hollow

  pigment 
  {
    color rgb 1
  }
}	

#declare FLOOR = 
plane 
{
  <0, 1, 0>, 0

  texture 
  {
    pigment 
    {
      color rgb 0.3
      quick_color rgb 1
    }
    finish 
    {
      ambient 0.2
    }
  }
}

#declare TEX_WOOD = 
texture 
{
  pigment 
  {
    wood

    color_map 
    { 
      [0.1 color rgb <0.60, 0.35, 0.20>]
      [0.9 color rgb <0.90, 0.65, 0.30>]
      [1.0 color rgb <0.60, 0.35, 0.20>]
    }
    turbulence <0.06, 0.1, 1000>
    scale <0.03, 0.03, 0.1>
    rotate <1, 1, 0>
  }

  normal 
  {
    bumps 0.2
    scale 0.6
  }
  
  finish
  {
    ambient 0.1
    diffuse 0.8
    phong 0.2
    phong_size 40
  }
}

#declare FRAME = 0.1;
#declare EPS = 0.000001;

#declare CABINET = 
union 
{

  // Cabinet body

  difference 
  {
    box 
    {
      <0, 0, -1.5>
      <1.2, 3, 1.5>
    }

    // Front depression
    box 
    {
      <1.3, FRAME, -1.5+FRAME>
      <1.2-0.05, 3-FRAME, 1.5-FRAME>
    }

    // Back depression
    box 
    {
      <-0.1, FRAME, -1.5+FRAME>
      <+0.05, 3-FRAME, 1.5-FRAME>
    }
    
    // Door clearance
    box 
    {
      <1.3, FRAME+EPS, -0.03>
      <0.5, 3-FRAME, 0.03>
    }
                
    // Left and right clearance
    box 
    {
      <1.3, FRAME, -1.5+FRAME+EPS>
      <0.5, 3-FRAME, -1.5+FRAME+0.03>
    }
    box 
    {
      <1.3, FRAME, 1.5-FRAME-EPS>
      <0.5, 3-FRAME, 1.5-FRAME-0.03>
    }
    
    // Lower clearance
    box 
    {
      <1.3, FRAME+EPS, -1.5+FRAME>
      <0.5, FRAME+0.03, 1.5-FRAME>
    }
  }

  // Handles
  box 
  {
    <1.1, 1.7, -0.26>
    <1.22, 2.1, -0.34>
  }

  box 
  {
    <1.1, 1.7, 0.26>
    <1.22, 2.1, 0.34>
  }

  // Top (only for the nicer texturing direction)
  box 
  {
    <0, 3, -1.5>
    <1.2, 3+EPS, 1.5>
    texture 
    {
      TEX_WOOD
      rotate <0, -1, -90>
    }
  }
  

  scale 1.2
          
  texture 
  {
    TEX_WOOD
    rotate <90, 0, 0>
  }
}

union 
{
  object 
  {
    FLOOR
  }

  object 
  {
    CABINET
    scale 0.42
    
    translate <3, 0, 0>
    rotate <0, 0, 0>
  }

  object 
  {
    CABINET
    scale 0.42
    
    translate <3, 0, 0>
    rotate <0, 90, 0>
  }

  object 
  {
    CABINET
    scale 0.42
    
    translate <3, 0, 0>
    rotate <0, 180, 0>
  }

  object 
  {
    CABINET
    scale 0.42
    
    translate <3, 0, 0>
    rotate <0, 270, 0>
  }

  scale 0.8
  translate <0, -0.5, 0>
}
